==> webkit2gtk_2.51.4.orig.tar.xz: webkitgtk-2.51.4/Source/JavaScriptCore/ftl/FTLValueRange.h <==
/*
 * Copyright (C) 2014 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */

#pragma once

#if ENABLE(FTL_JIT)

#include <JavaScriptCore/FTLAbbreviatedTypes.h>

namespace JSC { namespace FTL {

class ValueRange {
public:
    ValueRange()
        : m_begin(nullptr)
        , m_end(nullptr)
    {
    }
    
    ValueRange(LValue begin, LValue end)
        : m_begin(begin)
        , m_end(end)
    {
    }
    
    LValue begin() const { return m_begin; }
    LValue end() const { return m_end; }
    
    void decorateInstruction(LValue loadInstruction, unsigned rangeKind) const;
    
private:
    LValue m_begin;
    LValue m_end;
};

} } // namespace JSC::FTL

#endif // ENABLE(FTL_JIT)

==> webkit2gtk_2.51.90.orig.tar.xz: webkitgtk-2.51.90/Source/JavaScriptCore/ftl/FTLValueRange.h <==
/*
 * Copyright (C) 2014 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */

#pragma once

#include <wtf/Platform.h>

#if ENABLE(FTL_JIT)

#include "FTLAbbreviatedTypes.h"

namespace JSC { namespace FTL {

class ValueRange {
public:
    ValueRange()
        : m_begin(nullptr)
        , m_end(nullptr)
    {
    }
    
    ValueRange(LValue begin, LValue end)
        : m_begin(begin)
        , m_end(end)
    {
    }
    
    LValue begin() const { return m_begin; }
    LValue end() const { return m_end; }
    
    void decorateInstruction(LValue loadInstruction, unsigned rangeKind) const;
    
private:
    LValue m_begin;
    LValue m_end;
};

} } // namespace JSC::FTL

#endif // ENABLE(FTL_JIT)
